.. meta::
   :description: How-to guides for using Hydra and hydra-zen.

.. _hydra-zen-how-to:

How-To Guides
=============

These how-to guides are here to help hydra-zen users who are wondering: "How do I ___?". 
Our guides help you learn by having you do; they provide simple steps towards concrete 
objectives.

.. note::

   These guides focus solely on practical steps towards concrete 
   outcomes, and thus they do not explain *how* Hydra and hydra-zen work. To gain a 
   deeper understanding of the technical details here, please refer to the 
   :ref:`hydra-zen-reference` section of our documentation. Each page includes extensive
   examples and explanations.


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   how_to/configuring_experiments
   how_to/configure_hydra
   how_to/partial_config
   how_to/beartype
   how_to/using_scikit_learn
   how_to/pytorch_lightning
